@@ -1,6 +1,6 @@
 package Catmandu::Importer::SRU::Parser::picaxml;
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 use Moo;
 use PICA::Parser::XML;
@@ -8,7 +8,7 @@ use PICA::Parser::XML;
 sub parse {
     my ( $self, $record ) = @_;
 
-    my $xml = $record->{recordData};
+    my $xml = $record->{recordData}->toString();
     my $parser = PICA::Parser::XML->new( $xml ); 
 
     return $parser->next;
